/* ************************************************************************** */
/* PROGRAMA	: segundo_ejemplo.c                                           */
/* VERSION	: 1.0                                                         */
/* TARGET	: Kit eZ430-RF2500 - Microcontrolador MSP430F22574            */
/* DESCRIPCION	: Puertos, interrupciones y temporizadores                    */
/* RECURSOS	: Puerto P1, TA,  Pulsador S1, LED ROJO, LED VERDE            */
/* AUTOR	: Eva Gonzlez Parada (gonzalez@uma.es)                       */
/* FECHA	: 01/02/12                                                    */
/* ESQUEMA      : VLO= 12KHz (max) MCLK= SMCLK= DCO 1MHz                      */
/*              :  Botn S1 asociado a P1.2                                   */
/*              :  LED VERDE asociado a P1.1                                  */
/*              :  LED ROJO asociado a P1.0                                   */
/* ************************************************************************** */


#include "msp430x22x4.h"

/* ========================================================================== */
/* ============ PROTOTIPOS ================================================== */
/* ========================================================================== */
void Config_uC(void);
void Config_Perifericos();
void Config_TA(void );
/* ========================================================================== */
/* ============ PROGRAMA PRINCIPAL ========================================== */
/* ========================================================================== */
int main(void) {
        Config_uC();
	Config_Perifericos();
        Config_TA();
        __low_power_mode_3();// Funcin intrinseca que programa el modo de bajo
                             // consumo LPM3 y habilita las interrupciones
        while(1);
    
}//int main(void)

/* ========================================================================== */
/* ============ FUNCIONES =================================================== */
/* ========================================================================== */
void Config_uC(void) {

	WDTCTL = WDTPW + WDTHOLD;		// Detiene watchdog
	DCOCTL = 0;				// Frecuencia DCO (1MHz)
	BCSCTL1 = CALBC1_1MHZ;
	DCOCTL = CALDCO_1MHZ;

} // void Config_uC(void)


void Config_Perifericos(void) {
  P1DIR &= ~BIT2; // Terminal 2 del puerto 1 configurado como entrada
                  // asociado al botn de la placa (S1)
  P1OUT |= BIT2;  // Resistencia pullup para P1.2
  P1REN |= BIT2;  // Habilitacin de resistencia interna para P1.2
  P1IES |= BIT2;  // Activacin del flanco de bajada para P1.2
  P1IFG &= ~ BIT2;// Borrado del flag de interrupcin asociado a P1.2
  P1IE  |= BIT2;  // Habilitacin de las interrupciones del P1.2 
  
  P1DIR |=  BIT1; // Terminal P1.1 configurado como salida (LED VERDE)
  P1DIR |=  BIT0; // Terminal P1.0 configurado como salida (LED ROJO)
  P1OUT &= ~BIT0; // Salida P1.0 a 0 (LED ROJO) apagado
  P1OUT |=  BIT1;  // Salida P1.1 a 1 (LED VERDE) encendido
} // void Config_Perifericos(void)

void Config_TA(void ){

  BCSCTL3 |= LFXT1S_2;  //VLO =12Khz
  TACTL = MC_2+TASSEL_1;  // Modo continuo, fuente ACLK= VLO
  TACCTL0&= ~ CCIFG;      // Borrado del flag de interrupcin para contemplar
                          // las interrupciones que se producen a partir de ahora
  TACCTL0|= CCIE;         // Activacin de las interrupciones en modo comparacin
  TACCR0= TAR+0x2EE0;     // Carga del intervalo de tiempo de 1 segundo
}//void Config_TA( void )

/* ========================================================================== */
/* ============ RUTINAS TRATAMIENTO INTERRUPCION ============================ */
/* ========================================================================== */
#pragma vector = PORT1_VECTOR
__interrupt void RTI_Port1(void) {
  P1IFG &= ~BIT2;
  P1OUT ^= BIT0; // Conmuta el valor de la salida P1.0 (LED ROJO)
  P1OUT ^= BIT1; //Conmuta el valor de la salida P1.1 (LED VERDE)
} // void RTI_Port1(void)

#pragma vector = TIMERA0_VECTOR
__interrupt void RTI_TA0(void) {
  P1OUT ^= BIT0; // Conmuta el valor de la salida P1.0 (LED ROJO)
  P1OUT ^= BIT1; // Conmuta el valor de la salida P1.1 (LED VERDE)
  TACCR0= TAR+0x2EE0; //recarga la cuenta de 1 segundo para la comparacin
} // void RTI_TA0(void)